@@ -87,6 +87,9 @@ def list_namespaces():
     namespaces_list = namespaces.split("\n")
     return namespaces_list[1:]
 
+def get_default_namespace(cluster_config, namespace):
+    default_namespace = cluster_config.get(namespace, "default")
+    return default_namespace
 
 
 class ClusterManager(object):
@@ -387,10 +390,12 @@ class ClusterManager(object):
         return OrderedDict({k: getattr(self, k) for k in self.information_keys})
 
     def to_configmap(self, backup=False):
+        default_namespace = get_default_namespace(self.cluster_config, "defaultNamespace")
         return {
             "apiVersion": "v1",
             "kind": "ConfigMap",
             "metadata": {
+                "namespace": default_namespace,
                 "name": TRACKER_CONFIGMAP_BACKUP
                 + datetime.today().strftime("%Y%m%d-%H%M")
                 if backup
@@ -407,6 +412,7 @@ class ClusterManager(object):
         Update configmap on cluster with self
         We use json instead of YAML to avoid issues with boolean encoding
         """
+        self.update_default_namespace()
         run_cmd(
             f"echo '{json.dumps(self.to_configmap(backup=backup))}' | kubectl apply -f -",
             silent=True,
