@@ -45,11 +45,7 @@ def gw_info(info, session=None):
         None,
     )
     assert client_fs and indico_fs, "Missing a file share in your storage gateway"
-    return {
-        "gw_arn": gw_arn,
-        "indico_fs": indico_fs,
-        "client_fs": client_fs,
-    }
+    return {"gw_arn": gw_arn, "indico_fs": indico_fs, "client_fs": client_fs}
 
 
 def is_covered_by(cidr, bigger_cidr):
