@@ -24,15 +24,3 @@ function has_internet() {
       return 1 # False
   fi
 }
-
-function install_docker() {
-    # TODO: disable docker iptables update
-    if command -v docker >/dev/null 2>&1; then
-        docker --version
-    else
-        echo Installing docker with snap
-        snap install docker
-    fi
-    newgrp docker <<EONG
-EONG
-}
